/* This file is part of GEGL.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <https://www.gnu.org/licenses/>.
 */

#ifndef __GEGL_MEMORY_PRIVATE_H__
#define __GEGL_MEMORY_PRIVATE_H__


#define GEGL_ALIGNMENT 16
#define GEGL_ALIGN(n)             \
  (((n) + (GEGL_ALIGNMENT - 1)) / \
   GEGL_ALIGNMENT               * \
   GEGL_ALIGNMENT)


#endif  /* __GEGL_MEMORY_PRIVATE_H__ */
